# Generated by Django 3.2.4 on 2021-06-15 18:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("aa_bulletin_board", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="bulletin",
            name="slug",
            field=models.SlugField(allow_unicode=True, max_length=255, unique=True),
        ),
    ]
