CKEDITOR.plugins.setLang('youtube', 'eu', {
	button : 'Kapsulatu YouTube-ko bideoa',
	title : 'Kapsulatu YouTube-ko bideoa',
	txtEmbed : 'Itsatsi kapsulatzeko kodea hemen',
	txtUrl : 'Itsatsi YouTube-ko bideoaren URLa',
	txtWidth : 'Zabalera',
	txtHeight : 'Altuera',
	chkRelated : 'Erakutsi gomendatutako bideoak amaieran',
	txtStartAt : 'Hasi hemendik (ss edo mm:ss edo hh:mm:ss)',
	chkPrivacy : 'Gaitu pribatutasun hobetuko modua',
	chkOlderCode : 'Erabili kapsulatzeko kode zaharra',
	chkAutoplay: 'Erreproduzitu automatikoki',
	chkControls: 'Erakutsi erreproduzigailuaren kontrolak',
	noCode : 'Kapsulatzeko kode bat edo URL bat sartu behar duzu',
	invalidEmbed : 'Sartu duzun kapsulatzeko kodea ez da baliozkoa',
	invalidUrl : 'Sartu duzun URLa ez da baliozkoa',
	or : 'edo',
	noWidth : 'Zabalera sartu behar duzu',
	invalidWidth : 'Sartu baliozko zabalera bat',
	noHeight : 'Altuera sartu behar duzu',
	invalidHeight : 'Sartu baliozko altuera bat',
	invalidTime : 'Sartu baliozko hasierako denbora bat',
	txtResponsive : 'Egin moldagarria (ez ikusia egin zabalera eta altuerari, zabalerara doitu)',
	txtNoEmbed : 'Bideoaren irudia eta esteka soilik'
});
